@@ -1,5 +1,8 @@
 package Perinci::Sub::ConvertArgs::Argv;
 
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.05'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
@@ -8,8 +11,6 @@ use Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(convert_args_to_argv);
 
-our $VERSION = '0.04'; # VERSION
-
 our %SPEC;
 
 sub _json {
@@ -106,7 +107,7 @@ sub convert_args_to_argv {
 }
 
 1;
-#ABSTRACT: Convert hash arguments to command-line options (and arguments)
+# ABSTRACT: Convert hash arguments to command-line options (and arguments)
 
 __END__
 
@@ -120,7 +121,7 @@ Perinci::Sub::ConvertArgs::Argv - Convert hash arguments to command-line options
 
 =head1 VERSION
 
-This document describes version 0.04 of Perinci::Sub::ConvertArgs::Argv (from Perl distribution Perinci-Sub-ConvertArgs-Argv), released on 2014-07-18.
+This document describes version 0.05 of Perinci::Sub::ConvertArgs::Argv (from Perl distribution Perinci-Sub-ConvertArgs-Argv), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -128,6 +129,14 @@ This document describes version 0.04 of Perinci::Sub::ConvertArgs::Argv (from Pe
 
  my $res = convert_args_to_argv(args=>\%args, meta=>$meta, ...);
 
+=head1 SEE ALSO
+
+L<Perinci::CmdLine>, which uses this module for presenting command-line
+examples.
+
+L<Perinci::Sub::GetArgs::Argv> which does the reverse: converting command-line
+arguments to hash.
+
 =head1 FUNCTIONS
 
 
@@ -155,23 +164,21 @@ Whether to use positional arguments.
 
 For example, given this metadata:
 
-    {
-        v => 1.1,
-        args => {
-          arg1 => {pos=>0, req=>1},
-          arg2 => {pos=>1},
-          arg3 => {},
-        },
-    }
+ {
+     v => 1.1,
+     args => {
+       arg1 => {pos=>0, req=>1},
+       arg2 => {pos=>1},
+       arg3 => {},
+     },
+ }
 
-then under C<use_pos=0> the hash C<{arg1=>1, arg2=>2, arg3=>'a b'}> will be
+then under C<use_pos=0> the hash C<< {arg1=E<gt>1, arg2=E<gt>2, arg3=E<gt>'a b'} >> will be
 converted to C<['--arg1', 1, '--arg2', 2, '--arg3', 'a b']>. Meanwhile if
 C<use_pos=1> the same hash will be converted to C<[1, 2, '--arg3', 'a b']>.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -181,19 +188,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
-
-=head1 TODO
-
-Option to use/prefer cmdline_aliases.
-
-=head1 SEE ALSO
-
-L<Perinci::CmdLine>, which uses this module for presenting command-line
-examples.
-
-L<Perinci::Sub::GetArgs::Argv> which does the reverse: converting command-line
-arguments to hash.
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -201,7 +196,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Su
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-ConvertArgs-Argv>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-ConvertArgs-Argv>.
 
 =head1 BUGS
 
@@ -213,11 +208,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
